use ACS_2012_2016.dta , replace
*Reduce data to observations of interest                                                                               
drop if uhrswork ==0
drop if age < 16 | age > 64                                                                                          
drop if hispan == 9
********************************************************************************
**Create Race and Ethnicity categories
********************************************************************************
*1 - "non-Hispanic, Single-race White"
*2 - "non-Hispanic, Single-race Black" ///
*3 - "non-Hispanic, Single-race AIAN" ///
*4 - "Hispanic, Single-race White" ///
*5 - "Hispanic, Single-race Black" ///
*6 - "Hispanic, Single-race AIAN" ///
*7 - "non-Hispanic, White and AIAN" ///
*8 - "non-Hispanic, AIAN Other +" ///
*9 - "Hispanic, White and AIAN" ///
*10 - "Hispanic, AIAN Other +"

***Single Race non-Hispanic races
gen race_cat = 1 if race == 1 & hispan == 0 
replace race_cat = 2 if race == 2 & hispan == 0
replace race_cat = 3 if race == 3 & hispan == 0

***Single Race Hispanic races
replace race_cat = 4 if race == 1 & hispan != 0 
replace race_cat = 5 if race == 2 & hispan != 0
replace race_cat = 6 if race == 3 & hispan != 0


***Multi Race non-Hispanic AIAN categories 
replace race_cat = 7 if raced == 802 & hispan == 0
replace race_cat = 8 if raced == 830 & hispan == 0
replace race_cat = 8 if racamind == 2 & race_cat == . & hispan == 0

***Multi Race Hispanic AIAN categories 
replace race_cat = 9 if raced == 802 & hispan != 0
replace race_cat = 10 if raced == 830 & hispan != 0
replace race_cat = 10 if racamind == 2 & race_cat == . & hispan != 0
********************************************************************************
********************************************************************************
**Transform data similar to that done by Thomas Lemieux AER vol. 96 no. 3 2006 pp. 461-98
*Increasing Residual Wage Inequality: Composition Effects, Noisy Data or Rising Demand for Skill?
********************************************************************************
* Remove individuals with self-employment earnings more than 10% of wage and salary.                                  - Lemieux
gen hi_selfemp = 0 
replace hi_selfemp = 1 if incbus00/incwage > .1 & incwage !=0
drop if hi_selfemp == 1
drop hi_selfemp

preserve
import excel "/2016_acs_topcodes.xls", sheet("Sheet1") firstrow case (lower) clear
keep statefip inc*
rename inc* tc_inc*
save 2016_acs_topcodes, replace
restore
merge m:1 statefip using 2016_acs_topcodes

*Drop Puerto Rico (no ACS observations meeting above conditions
drop if statefip == 72

* Weight observations by annual hours of work                                                                        - Lemieux
********************************************************************************
* Annual weeks worked is intervalled
* 0 N/A (or Missing)
* 1 1-13 weeks
* 2 14-26 weeks
* 3 27-39 weeks
* 4 40-47 weeks
* 5 48-49 weeks
* 6 50-52 weeks
********************************************************************************

gen wkswork_nbr = 0
replace wkswork_nbr = 7 if wkswork2 == 1
replace wkswork_nbr = 20 if wkswork2 == 2
replace wkswork_nbr = 33 if wkswork2 == 3
replace wkswork_nbr = 43.5 if wkswork2 == 4
replace wkswork_nbr = 48.5 if wkswork2 == 5
replace wkswork_nbr = 51 if wkswork2 == 6

gen hr_wt = wkswork_nbr*uhrswork*perwt if incwage !=0
gen hrs_yr = wkswork_nbr*uhrswork
gen hrly_wage = incwage/hrs_yr if incwage !=0
********************************************************************************
* Multiply topcoded wages by 1.4 after applying the folowing adjustments                                               - Lemieux
* Top coding system changed in 2011 all incomes above the topcode are rounded to two significant digits 
* and then exchanged among individuals within a bounded interval. This is called a "rank proximity procedure".
* Add data for 2016 ACS state top-codes https://usa.ipums.org/usa/volii/2016acs_topcodes.shtml
********************************************************************************
********************************************************************************
gen `incwage_tc = incwage
replace incwage_tc = incwage*1.4 if incwage>=tc_incwage & incwage !=0
replace hrly_wage = incwage_tc/hrs_yr if incwage>=tc_incwage & incwage !=0

********************************************************************************
* No need to adjust for inflation because dollar amounts are standardized to dollars in the final year
* https://usa.ipums.org/usa-action/variables/INCWAGE#description_section
* Remove observations with an hourly wage of less than $1 (2.7982) or more than $100 (279.82)in 1979 dollars           - Lemieux
* PCE in 1979 is 37.251 in 2016 it is 104.235 when 2012 = 100.
* Remove observations with negative potential experience
********************************************************************************
gen low_wage = 1 if hrly_wage < 2.7982 & incwage != 0
gen hi_wage = 1 if hrly_wage > 279.82 & incwage !=0
drop if hi_selfemp == 1
drop if low_wage == 1
drop if hi_wage == 1
drop hi_selfemp low_wage hi_wage

********************************************************************************
** Remove observations with negative potential experience
********************************************************************************
*Reduce to those with between 0 and 39 Years of Potential Interest Number of 
*years of schooling is imputed based upon method 3 discussed in ``Estimation of 
*Sheepskin Effects and Returns to Schooling Using the Old and the New CPS Measures 
*of Educational Attainment" by Jin Heum Park 1994 years of potential experience 
*are calculated to be the age minus the assigned years of education minus 6
*
*0 yrs if no school
*3 yrs if 1-4th
*7 yrs if 5-8th
*9yrs if 9th
*10yrs if 10th
*11yrs if 11th
*12yrs if no diploma or hs grad
*13.5 yrs if some college
*14 if associates
*16 if bachelors
*17.5 if masters or prof deg 
*18 yrs doctorate 
********************************************************************************
generate Yrs_school = 0 if educ ==0
replace Yrs_school = 3 if educ == 1
replace Yrs_school = 7 if educ == 2
replace Yrs_school = 9 if educ == 3
replace Yrs_school = 10 if educ == 4
replace Yrs_school = 11 if educ == 5
replace Yrs_school = 12 if educ == 6 & educd == 61
replace Yrs_school = 12 if educ == 6 & educd == 63
replace Yrs_school = 12 if educ == 6 & educd == 64
replace Yrs_school = 13.5 if educ == 6 & educd == 53
replace Yrs_school = 13.5 if educ == 7
replace Yrs_school = 14 if educ == 8
replace Yrs_school = 16 if educ == 10 
replace Yrs_school = 17.5 if educ == 11 & educd ==  114
replace Yrs_school = 17.5 if educ == 11 & educd ==  115
replace Yrs_school = 18 if educ == 11 & educd ==  116

generate Exp_pot = round(max(age -Yrs_school - 6,0),1)

drop if Exp_pot <= 0

save hrlywage_5yr2016, replace




cd "I:\Paper\IncomeSeg"

/*
1. Theildeco is used for the inequality decomposition
2. Create race-homeland specific files from the master file
3. The master file is the all_combined file genderated by the hourly wage code
calculate the overall T, between- and within group T, the quantile T, and the BIC
*/

use hrlywage_5yr2016, clear
keep if inlist(race_cat, 3,6,7,8,9,10)
gen race_str=""
replace race_str="NHSR" if race_cat==3
replace race_str="HSR" if race_cat==6
replace race_str="NHW" if race_cat==7
replace race_str="NHO" if race_cat==8
replace race_str="HW" if race_cat==9
replace race_str="HO" if race_cat==10
save AIAN_subgrp, replace

use AIAN_subgrp, clear
foreach xxx in NHSR NHW NHO HSR HW HO {
	preserve
	keep if race_str=="`xxx'"
	save `xxx', replace
	restore
}

foreach file in NHSR NHW NHO HSR HW HO {
	use `file', clear
	forval i=1/2 {
		preserve
		keep if homeland==`i'
		save `file'`i', replace
		restore
	}
}
	

/* 
1. Run macro through all race-homeland specific files
2. The files are NHW_HL AIAN_HL NHB_HL AIAN_NHL NHB_NHL
3. However, I didn't have results for NHW_NHL after waiting for a whole night...
4. Report descriptive stats for hourly wage
5. Compute and decompose T
*/

foreach file in NHSR1 NHW1 NHO1 HSR1 HW1 HO1 NHSR2 NHW2 NHO2 HSR2 HW2  HO2 {
clear
use `file', clear

keep if labforce==2 /*drop cases that were not in laborforce or reported missing income data*/
drop if empstat==2 /* drop cases that reported unemployed*/
drop if hrly_wage==0

/*comparing hourly wage between male and female*/
sum hrly_wage [fw=perwt]
gen W_avg=r(mean)

forval i=1/2 {
sum hrly_wage if sex==`i'
gen W_nsex`i'=r(N)
sum hrly_wage if sex==`i' [fw=perwt], detail
gen W_nwsex`i'=r(N)
gen W_msex`i'=r(mean)
gen W_p10sex`i'=r(p10)
gen W_p50sex`i'=r(p50)
gen W_p90sex`i'=r(p90)
}

twoway kdensity hrly_wage if sex==1, lwidth(thick) || kdensity hrly_wage  if sex==2, lpattern(dash) lwidth(thick) xtitle("") ytitle("") legend(off) 
graph export `file'.emf, as(emf) replace

/*
For decomposition, I chose to contrast two percentiles, the top 10% versus the remaining 90%
m(2): Method 2 to contrast the top and bottom percentiles 
*/

theildeco hrly_wage [aw=perwt], byg(sex) 
gen T_all=r(Theil)
gen T_bg=r(between_T)
gen T_wg=r(within_T)
gen T_sd=r(shared_within)
gen T_dd=T_wg-T_sd

gen T_pct_bg=T_bg/T_all*100
gen T_pct_sd=T_sd/T_wg*100
gen T_pct_dd=100-T_pct_sd

theildeco hrly_wage [aw=perwt], byg(sex) m(2) 

gen T_tb=r(TopBotlnR)

mat A=r(within_q_between)
mat B=r(within_q_within)
mat AA=A'
mat BB=B'
svmat AA, names(T_wqb)
svmat BB, names(T_wqw)

collapse (mean) W_* T_* 
gen file="`file'"
save temp_`file', replace

}

use temp_NHSR1, clear
append using temp_NHSR2 temp_NHW1 temp_NHW2 temp_NHO1 temp_NHO2 temp_HSR1 temp_HSR2 temp_HW1 temp_HW2 temp_HO1 temp_HO2 
save theildeco_6grp, replace

/*
confirm BIC calculation
gen x= T_wqb2/ T_wqb1
gen y=log(x)
tab y
gen z=y*2
tab z
*/

/* some random codes to manipulate the file for reporting the results*/

use theildeco_6grp, clear
preserve
drop T_*
save theildeco_6grp_W, replace
restore
drop W_*
save theildeco_6grp_T, replace

use theildeco_6grp_T, clear
gen hl=1 if index(file, "1")
replace hl=2 if index(file, "2")

gen grp=regexs(0) if regexm(file, "[A-Z]*")
drop file

reshape wide T_all-T_wqw2, i(grp)j(hl)


use theildeco_6grp_W, clear
gen hl=1 if index(file, "1")
replace hl=2 if index(file, "2")

gen grp=regexs(0) if regexm(file, "[A-Z]*")
drop file

reshape long W_nsex W_nwsex W_msex W_p10sex W_p50sex W_p90sex, i(grp hl) j(sex)

sort sex grp

